# src/ecommerce_toolkit/providers/shopify.py
import requests
from typing import List
from .base import EcommerceProvider
from ..models.product import Product

class ShopifyProvider(EcommerceProvider):
    def __init__(self, shop_url: str, access_token: str):
        self.base_url = f"https://{shop_url}/admin/api/2024-01"
        self.headers = {
            "X-Shopify-Access-Token": access_token,
            "Content-Type": "application/json"
        }
    
    def get_products(self) -> List[Product]:
        response = requests.get(
            f"{self.base_url}/products.json",
            headers=self.headers
        )
        response.raise_for_status()
        products = response.json()["products"]
        return [
            Product(
                id=str(p["id"]),
                name=p["title"],
                price=float(p["variants"][0]["price"]),
                stock=int(p["variants"][0]["inventory_quantity"]),
                description=p.get("body_html")
            )
            for p in products
        ]
    
    def get_product(self, product_id: str) -> Product:
        response = requests.get(
            f"{self.base_url}/products/{product_id}.json",
            headers=self.headers
        )
        response.raise_for_status()
        p = response.json()["product"]
        return Product(
            id=str(p["id"]),
            name=p["title"],
            price=float(p["variants"][0]["price"]),
            stock=int(p["variants"][0]["inventory_quantity"]),
            description=p.get("body_html")
        )
    
    def search_products(self, query: str) -> List[Product]:
        response = requests.get(
            f"{self.base_url}/products.json",
            params={"title": query},
            headers=self.headers
        )
        response.raise_for_status()
        products = response.json()["products"]
        return [
            Product(
                id=str(p["id"]),
                name=p["title"],
                price=float(p["variants"][0]["price"]),
                stock=int(p["variants"][0]["inventory_quantity"]),
                description=p.get("body_html")
            )
            for p in products
        ]
